@@ -4,6 +4,7 @@ import importlib
 import logging
 import pathlib
 import platform
+import warnings
 from datetime import datetime
 from typing import List, Optional, Tuple
 
@@ -207,6 +208,26 @@ class TartufoCLI(click.MultiCommand):
     show_default=True,
     help="Enable or disable timestamps in logging messages.",
 )
+@click.option(
+    "-b64",
+    "--b64-entropy-score",
+    default=4.5,
+    show_default=True,
+    help="Modify the base64 entropy score. If a value greater than the default is "
+    "specified, tartufo lists higher entropy base64 strings (longer or more randomized "
+    "strings). A lower value lists lower entropy base64 strings (shorter or less "
+    "randomized strings).",
+)
+@click.option(
+    "-hex",
+    "--hex-entropy-score",
+    default=3.0,
+    show_default=True,
+    help="Modify the hexadecimal entropy score. If a value greater than the default is "
+    "specified, tartufo lists higher entropy hexadecimal strings (longer or more randomized "
+    "strings). A lower value lists lower entropy hexadecimal strings (shorter or less "
+    "randomized strings).",
+)
 # The first positional argument here would be a hard-coded version, hence the `None`
 @click.version_option(None, "-V", "--version")
 @click.pass_context
@@ -253,6 +274,8 @@ def main(ctx: click.Context, **kwargs: config.OptionTypes) -> None:
         log_format = " ".join(["[%(asctime)s]", log_format])
     handler.setFormatter(logging.Formatter(log_format))
     logger.addHandler(handler)
+    # Show deprecation warnings to the console by default
+    warnings.simplefilter("always", DeprecationWarning)
 
 
 @main.resultcallback()  # type: ignore
